@@ -66,7 +66,7 @@ class Lexer(object):
             elif c == "-":
                 return LexToken(self, "MINUS")
             elif c == ",":
-                return LexToken(self, "COMMA")
+                return self.lexComma()
             elif c == "=":
                 return LexToken(self, "EQUAL")
             elif c == "[":
@@ -126,7 +126,23 @@ class Lexer(object):
             # If we're done with the comment, return!
             if nested == 0:
                 return True
-            
+    
+    def lexComma(self):
+
+        while True:
+            c = self.peek()
+
+            if c.isspace():
+                self.next()
+                continue
+
+            if c == "]":
+                return LexToken(self, "COMMAEND")
+
+            break
+
+        return LexToken(self, "COMMA")
+
     def lexId(self):
         
         startPos = self.pos+1
@@ -223,7 +239,7 @@ class Lexer(object):
         
     def lexString(self):
         
-        startPos = self.pos+1
+        b = []
         braces = 0
         
         while True:
@@ -237,18 +253,30 @@ class Lexer(object):
             # If we hit a newline, then its an error
             if c == '\n':
                 return self.createErr("Newline before string closed")
+
+            # If we're escaping a quote, then escape the quote
+            if c == '\\':
+                n = self.next()
+                if n == '"':
+                    c = n
+                elif n == 'n':
+                    c = '\n'
+                else:
+                    self.backup()
                 
             if braces == 0 and c == "$" and self.peek() == "{":
                 braces = 1
-                c = self.next()    
+                b.append(c)
+                c = self.next()   
             elif braces > 0 and c == "{":
                 braces += 1
                 
             if braces > 0 and c == "}":
                 braces -= 1
-                
-        value = self.input[startPos:self.pos]
-        return LexToken(self, "STRING", value)
+
+            b.append(c)
+        
+        return LexToken(self, "STRING", ''.join(b))
     
     def next(self):
         
